{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
        ./hardware-configuration.nix
        ../../common/common.nix
        ../../common/netdata.nix
        ./matrix.nix
    ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "luxon";
  networking.useDHCP = false;
  networking.interfaces.ens18.useDHCP = true;
  networking.interfaces.ens18.mtu = 1420;
  networking.interfaces.ens18.ipv6.addresses = [{
    address = "2a01:4f8:c010:61dc:200::500:23";
    prefixLength = 72;
  }];

  networking.defaultGateway6 = {
    address = "2a01:4f8:c010:61dc:200::1";
    interface = "ens18";
  };

  clerie.monitoring = {
    enable = true;
    id = "204";
    privKeyFile = "/run/keys/wg-luxon_priv";
    pubkey = "QAcy1H4ze8fkTbhkoMx58S48FhitQmqPClUfFduj6Vw=";
  };


  services.postgresql = {
    enable = true;
    package = pkgs.postgresql_12;
  };
  services.prometheus.exporters.postgres = {
    enable = true;
    port = 9101;
    runAsLocalSuperUser = true;
    openFirewall = true;
    firewallFilter = "-i wg-monitoring -p tcp -m tcp --dport 9101";
  };
}